@@ -1,7 +1,7 @@
 from genericpath import exists
 import os
 from pywebvue.utils import read_file_as_base64_url
-from trame.html import Span, vuetify
+from trame.html import Span, vuetify, Triggers
 from trame import base_directory, get_app_instance
 
 import pywebvue
@@ -13,9 +13,23 @@ LOGO_PATH = os.path.abspath(
 
 
 class FullScreenPage:
+    """
+    A layout that takes the whole screen.
+
+    :param name: Text for this page's browser tab (required)
+    :type name: str
+    :param favicon: Filename of image for this page's browser tab
+    :type favicon: str
+    :param on_ready: Function to run on startup
+    :type on_ready: function
+
+    >>> trame.start(FullScreenPage("Simple Page"))
+    """
+
     def __init__(self, name, favicon=None, on_ready=None):
         self.name = name
         self.favicon = None
+        self.triggers = Triggers("_js_trame_triggers")
         if os.path.exists(LOGO_PATH):
             self.favicon = read_file_as_base64_url(LOGO_PATH)
         self.on_ready = on_ready
@@ -23,6 +37,9 @@ class FullScreenPage:
         self.children = self._app.children
         self._current_root = self._app
 
+        # Always add triggers
+        self._app.children += [self.triggers]
+
         if favicon:
             file_path = os.path.join(base_directory(), favicon)
             if os.path.exists(file_path):
@@ -54,6 +71,15 @@ class FullScreenPage:
 
 
 class SinglePage(FullScreenPage):
+    """
+    A layout that takes the whole screen, adding an App bar for a header and a footer.
+
+    :param name: Text for this page's browser tab (required)
+    :type name: str
+
+    >>> trame.start(SinglePage("Page with header / app bar"))
+    """
+
     def __init__(self, name):
         super().__init__(name)
         self.toolbar = vuetify.VAppBar(app=True)
@@ -101,6 +127,21 @@ class SinglePage(FullScreenPage):
 
 
 class SinglePageWithDrawer(SinglePage):
+    """
+    A layout that takes the whole screen, adding an App bar for a header, a drawer, and a footer.
+
+    :param name: Text for this page's browser tab (required)
+    :type name: str
+    :param show_drawer: Whether the drawer is open. Default True
+    :type show_drawer: bool
+    :param width: How many pixels wide the drawer should be
+    :type width: Number
+    :param show_drawer_name: The name referencing the drawer's state. Default "drawerOpen".
+    :type show_drawer_name: str
+
+    >>> trame.start(SinglePageWithDrawer("Page with drawer"))
+    """
+
     def __init__(
         self, name, show_drawer=True, width=200, show_drawer_name="drawerOpen"
     ):
